<?php
namespace Models;

// Модель для работы с дисплеем покупателя
class Cd extends \DB\SQL\Mapper{
	public $cd, $db, $f3, $sets, $method='POST', $messages;

	public function __construct($db, $f3) {
		parent::__construct($db, 'cd_settings' ); // подключаемся к таблице с настройками
		$this->f3=$f3;
		$this->db=$db;
		$this->messages=new \Models\Messages();
		$this->sets=$this->get_cd();
		if($this->sets['driver']!='') {
			if(file_exists($this->sets['driver'].'/server.py')) {
				$this->cd=new Cd_python($f3, $this->sets);
			}
			elseif(file_exists($this->sets['driver'].'/server.php')) {
				require_once($this->sets['driver'].'/server.php');
				$this->cd=new Cd_php($f3, $this->sets);
			}
			else {
				echo 'Ошибка';
			}
		}
		$this->f3->set('ONERROR', function(){
			if($this->f3->get('GET.cd_unset')) {
				$sql="UPDATE cd_settings SET active=0";
				$this->db->exec($sql);
				$this->f3->reroute('/');
			}
			$this->f3->set('page_data', $this->messages->page_data('cd_error'));
			echo \Template::instance()->render('layout.htm');
			//$this->f3->reroute($this->f3->get('URI'));
		});
	}

	// Узнаем настройки дисплея покупателя
	function get_cd() {
		$this->reset();
		$this->load();
		$sets=$this->cast();
		return $sets;
	}

	// Сохраняем настройки дисплея покупателя
	function save_cd($post) {
		$this->reset();
		$this->get_cd();
		$this->copyFrom($post);
		if($this->save()===false) {
			return array(
				'success'=>false,
				'txt'=>'db_error'
			);
		}
		return array(
			'success'=>true,
			'txt'=>'save_successful'
		);
	}

	// Печать на дисплее покупателя
	function print($txt, $timeout=30) {
		if(!$this->sets['active']) return;
		$this->cd->print($txt, $timeout);
	}

	// Очистить дисплей покупателя
	function clear_cd() {
		$this->print("p;;;");
	}

	// Текст закрытой кассы
	function close_txt() {
		$this->clear_cd();
		$this->print($this->sets['close_txt']);
	}

	// Текст готовности к новой продаже
	function seller_txt() {
		$this->clear_cd();
		$this->print($this->sets['seller_txt']);
	}

	// Текст добавления товара в чек
	function print_line($line, $count) {
		$this->clear_cd();
		$price=$line['price']+($line['price']*($line['vat']/100))*max(0, $line['vat_type']);
		$txt="p;".$line['product_title'].";";
		$txt.=$count."x".number_format($price, 2, '.', '')."=".number_format($price*$count, 2, '.', '').";";
		$this->print($txt);
	}

	// Текст при оплате чека
	function total_price($sum, $pay) {
		$this->clear_cd();
		$txt="p;Итого:".number_format($sum, 2, '.', '').";";
		if($pay-$sum>0) {
			$txt.="Сдача:".number_format($pay-$sum, 2, '.', '');
		}
		$txt.=";";
		$this->print($txt);
	}

	// Список драйверов
	function get_drivers() {
		$drivers=array();
		$displays_dir=$this->f3->get('displays_dir');
		$dirs=scandir($displays_dir); // Ищем все драйвера
		if($dirs) {
			foreach ($dirs as $d) {
				$folder=$displays_dir.$d;
				$file=$folder.'/server.config';
				if(is_dir($folder) && file_exists($file)) {
					$config=parse_ini_file($file);
					if($config) {
						$drivers[$folder]=array(
							'title'=>$config['ServerName'],
							'path'=>$folder
						);
					}
				}
			}
		}

		return $drivers;
	}
}
